@@ -149,6 +149,10 @@ class HailAzureBlobPath(AzureBlobPath):
 
         return valid
 
+    @property
+    def drive(self) -> str:
+        return self.account / self.container
+
     @property
     def account(self) -> str:
         """
